@@ -30,7 +30,7 @@ print $som->result();
 # Note that you have to look both the proxy and the xmlns attribute 
 # set on the GetWeather SOAP::Data object from the WSDL.
 
-use SOAP::Lite; # +trace;
+use SOAP::Lite +trace;
 $soap = SOAP::Lite->new()->on_action( sub { join'/', @_ } )
   ->proxy("http://www.webservicex.net/globalweather.asmx");     # from WSDL
 $som = $soap->call(
